﻿using System.Collections.Generic;
using System.Linq;
using Infragistics.Web.Mvc;
using MvcApplication2.Models.Entities;

namespace MvcApplication2.Models
{
    public class IndexViewModel
    {
        public GridModel GridModel { get; set; }

        public IndexViewModel()
        {
            GridModel = new GridModel { DataSource = GetDataSource() };
            InitializeGrid(GridModel);
        }

        private static void InitializeGrid(GridModel model)
        {
            model.Width = "1000px";
            model.RenderCheckboxes = true;
            model.AutoGenerateColumns = false;
            model.Columns.Add(new GridColumn("Name", "Name", "string", "300px"));
            model.Columns.Add(new GridColumn("Company", "Company", "string", "300px"));



            model.Features.Add(new GridFiltering());
            model.Features.Add(new GridSorting());
            model.Features.Add(new GridGroupBy());
            model.Features.Add(new GridResizing());
            model.Features.Add(new GridHiding());

            var contactDataLayout = new GridColumnLayoutModel
            {
                Key = "ContactDatas",
                RenderCheckboxes = true,
                ShowHeader = true,
                Caption = "Contact Data",
                AutoGenerateColumns = false,
                Width = "800px"
            };
            contactDataLayout.Columns.Add(new GridColumn("Email", "EmailAddress", "string", "250px"));
            contactDataLayout.Columns.Add(new GridColumn("Twitter", "TwitterAccount", "string", "250px"));

            contactDataLayout.Features.Add(new GridSorting());
            contactDataLayout.Features.Add(new GridResizing());

            model.ColumnLayouts.Add(contactDataLayout);

            var obsoleteContactDataLayout = new GridColumnLayoutModel
            {
                Key = "ObsoleteContactDatas",
                RenderCheckboxes = true,
                ShowHeader = true,
                Caption = "Obsolete Contact Data",
                AutoGenerateColumns = false,
                Width = "800px"
            };
            obsoleteContactDataLayout.Columns.Add(new GridColumn("Email", "EmailAddress", "string", "250px"));
            obsoleteContactDataLayout.Columns.Add(new GridColumn("Twitter", "TwitterAccount", "string", "250px"));

            obsoleteContactDataLayout.Features.Add(new GridSorting());
            obsoleteContactDataLayout.Features.Add(new GridResizing());

            model.ColumnLayouts.Add(obsoleteContactDataLayout);

        }

        private static IQueryable GetDataSource()
        {
            var customerList = new List<Customer>()
            {
                new Customer()
                {
                    Name = "George", 
                    Company = "Ikea", 
                    ContactDatas = new List<ContactData>()
                    {
                        new ContactData() { EmailAddress = "george@ikea.com"},
                        new ContactData() {TwitterAccount = "1234", EmailAddress = "sgsdg"}
                    }
                },
                new Customer() {Name = "Fred", Company = "Microsoft",  
                    ObsoleteContactDatas = new List<ContactData>()
                    {
                        new ContactData() { EmailAddress = "Fred@Microsoft.com"},
                    }},
                new Customer() {Name = "Leopold", Company = string.Empty,  
                    ContactDatas = new List<ContactData>()
                    {
                        
                    }},
                new Customer() {Name = "Margie", Company = null,  
                    ObsoleteContactDatas = new List<ContactData>()
                    {
                        new ContactData() { EmailAddress = "Margie@hotmail.com"},
                    }},
                new Customer() {Name = "Geraldine", Company = "Volvo",  
                    ContactDatas = new List<ContactData>()
                    {
                        new ContactData() { EmailAddress = "Geraldine@Volvo.com"},
                    }
                }
            };

            return customerList.AsQueryable();
        }
    }
}